@@ -1,5 +1,5 @@
-# vectorFile.pm version 1.01
-# (Last updated $Id: vectorFile.pm,v 1.4 2005/12/11 22:37:02 sidz1979 Exp $)
+# vectorFile.pm version 1.03
+# (Last updated $Id: vectorFile.pm,v 1.5 2006/02/19 19:11:09 sidz1979 Exp $)
 #
 # Package used by WordNet::Similarity::vector module that
 # computes semantic relatedness of word senses in WordNet
@@ -33,6 +33,32 @@
 
 package vectorFile;
 
+=head1 NAME
+
+vectorFile - Provides access to the word vectors database.
+
+=head1 SYNOPSIS
+
+  use vectorFile;
+
+  my ($dCount, $dims, $vecRef) = vectorFile->readVectors($filename);
+
+  vectorFile->writeVectors($fname, $dCount, $dims, $vecRef);
+
+=head1 DESCRIPTION
+
+This module provides a read/write interface into the word vectors data
+file. This module is used by WordNet::Similarity::vector and
+WordNet::Similarity::vector_pairs as an interface into the word
+vectors database. This module abstracts the format of the data file
+away from the user.
+
+=head2 Methods
+
+=over
+
+=cut
+
 use strict;
 use Exporter;
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
@@ -45,7 +71,19 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
 @EXPORT = ();
 
-$VERSION = '1.01';
+$VERSION = '1.03';
+
+=item readVectors
+
+This method reads in a word vectors file, and returns the document count,
+the words corresponding to the dimensions of the vectors, and a reference
+to an array containing the list of word vectors. 
+
+Parameters: $file -- the file name of the word vectors file.
+
+Returns: ($dCount, $dims, $vecRef)
+
+=cut
 
 # Read the word vectors from a file.
 sub readVectors
@@ -126,6 +164,18 @@ sub readVectors
     return ($docCount, $dimensions, $vectors);
 }
 
+=item writeVectors
+
+This method writes out a list of word vectors to the word vectors file. 
+
+Parameters: $fname, $dCount, $dims, $vecRef
+
+Returns: none
+
+=back
+
+=cut
+
 # Write the word vectors to a file.
 sub writeVectors
 {
@@ -167,3 +217,59 @@ sub writeVectors
 }
 
 1;
+
+__END__
+
+=head1 SEE ALSO
+
+perl(1), WordNet::Similarity(3), WordNet::QueryData(3)
+
+http://www.cs.utah.edu/~sidd
+
+http://wordnet.princeton.edu
+
+http://www.ai.mit.edu/~jrennie/WordNet
+
+http://groups.yahoo.com/group/wn-similarity
+
+=head1 AUTHORS
+
+ Ted Pedersen, University of Minnesota Duluth
+ tpederse at d.umn.edu
+
+ Siddharth Patwardhan, University of Utah, Salt Lake City
+ sidd at cs.utah.edu
+
+=head1 BUGS
+
+None.
+
+To report bugs, go to http://groups.yahoo.com/group/wn-similarity/ or
+e-mail "S<tpederse at d.umn.edu>".
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (c) 2005, Ted Pedersen and Siddharth Patwardhan
+
+This program is free software; you can redistribute it and/or
+modify it under the terms of the GNU General Public License
+as published by the Free Software Foundation; either version 2
+of the License, or (at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to
+
+   The Free Software Foundation, Inc.,
+   59 Temple Place - Suite 330,
+   Boston, MA  02111-1307, USA.
+
+Note: a copy of the GNU General Public License is available on the web
+at L<http://www.gnu.org/licenses/gpl.txt> and is included in this
+distribution as GPL.txt.
+
+=cut
